@@ -26,10 +26,12 @@ def check_output_format(output='', format=''):
 
     if success:
         if output != '':
-            output_path = os.path.dirname(output)
+            basename_extension = ''
+            if not os.path.isdir(output):
+                output_path = os.path.dirname(output)
 
-            basename = os.path.basename(output)
-            basename_file, basename_extension = os.path.splitext(basename)
+                basename = os.path.basename(output)
+                basename_file, basename_extension = os.path.splitext(basename)
             if basename_extension:
                 find_ext = False
                 for _format, _ext in SUPPORT_FORMAT.items():
@@ -57,12 +59,11 @@ def write_output_file(output_file_without_ext, file_extension, sheet_list, exten
     result_file = output_file_without_ext + file_extension
 
     if file_extension == '':
-        success, msg = write_excel_and_csv(output_file_without_ext, sheet_list, False, extended_header)
-        result_file = f"{output_file_without_ext}.xlsx, {output_file_without_ext}.csv"
+        success, msg, result_file = write_excel_and_csv(output_file_without_ext, sheet_list, False, extended_header)
     elif file_extension == '.xlsx':
         success, msg = write_result_to_excel(result_file, sheet_list, extended_header)
     elif file_extension == '.csv':
-        success, msg = write_result_to_csv(result_file, sheet_list)
+        success, msg, result_file = write_result_to_csv(result_file, sheet_list)
     elif file_extension == '.json':
         success, msg = write_opossum(result_file, sheet_list)
     else:
